This ICU4X crate is deprecated.
You can get the same functionality as this crate by using the code found in ICU4X’s examples/cargo/harfbuzz directory.
This ICU4X crate is deprecated.
You can get the same functionality as this crate by using the code found in ICU4X’s examples/cargo/harfbuzz directory.